/********************************************************************************
** Form generated from reading UI file 'KgvPageLayoutColumnsBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KGVPAGELAYOUTCOLUMNSBASE_H
#define UI_KGVPAGELAYOUTCOLUMNSBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KgvPageLayoutColumnsBase
{
public:
    QGridLayout *gridLayout;
    QFrame *columnSpacingPane;
    QLabel *textLabel1;
    QLabel *labelSpacing;
    QSpacerItem *spacer1;
    QFrame *previewPane;
    QSpinBox *nColumns;

    void setupUi(QWidget *KgvPageLayoutColumnsBase)
    {
        if (KgvPageLayoutColumnsBase->objectName().isEmpty())
            KgvPageLayoutColumnsBase->setObjectName("KgvPageLayoutColumnsBase");
        KgvPageLayoutColumnsBase->resize(362, 169);
        gridLayout = new QGridLayout(KgvPageLayoutColumnsBase);
        gridLayout->setObjectName("gridLayout");
        columnSpacingPane = new QFrame(KgvPageLayoutColumnsBase);
        columnSpacingPane->setObjectName("columnSpacingPane");
        columnSpacingPane->setFrameShape(QFrame::NoFrame);
        columnSpacingPane->setFrameShadow(QFrame::Raised);

        gridLayout->addWidget(columnSpacingPane, 1, 1, 1, 1);

        textLabel1 = new QLabel(KgvPageLayoutColumnsBase);
        textLabel1->setObjectName("textLabel1");

        gridLayout->addWidget(textLabel1, 0, 0, 1, 1);

        labelSpacing = new QLabel(KgvPageLayoutColumnsBase);
        labelSpacing->setObjectName("labelSpacing");

        gridLayout->addWidget(labelSpacing, 1, 0, 1, 1);

        spacer1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacer1, 2, 0, 1, 2);

        previewPane = new QFrame(KgvPageLayoutColumnsBase);
        previewPane->setObjectName("previewPane");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(previewPane->sizePolicy().hasHeightForWidth());
        previewPane->setSizePolicy(sizePolicy);
        previewPane->setFrameShape(QFrame::NoFrame);
        previewPane->setFrameShadow(QFrame::Raised);

        gridLayout->addWidget(previewPane, 0, 2, 3, 1);

        nColumns = new QSpinBox(KgvPageLayoutColumnsBase);
        nColumns->setObjectName("nColumns");
        nColumns->setMinimum(1);
        nColumns->setMaximum(16);

        gridLayout->addWidget(nColumns, 0, 1, 1, 1);

#if QT_CONFIG(shortcut)
        textLabel1->setBuddy(nColumns);
#endif // QT_CONFIG(shortcut)

        retranslateUi(KgvPageLayoutColumnsBase);

        QMetaObject::connectSlotsByName(KgvPageLayoutColumnsBase);
    } // setupUi

    void retranslateUi(QWidget *KgvPageLayoutColumnsBase)
    {
        textLabel1->setText(tr2i18n("Columns:", nullptr));
        labelSpacing->setText(tr2i18n("Column spacing:", nullptr));
        (void)KgvPageLayoutColumnsBase;
    } // retranslateUi

};

namespace Ui {
    class KgvPageLayoutColumnsBase: public Ui_KgvPageLayoutColumnsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KGVPAGELAYOUTCOLUMNSBASE_H

