/****************************************************************************
** Meta object code from reading C++ file 'KgvPageLayoutSize.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kgraphviewer-26.04.3/src/part/KgvPageLayoutSize.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KgvPageLayoutSize.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17KgvPageLayoutSizeE_t {};
} // unnamed namespace

template <> constexpr inline auto KgvPageLayoutSize::qt_create_metaobjectdata<qt_meta_tag_ZN17KgvPageLayoutSizeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KgvPageLayoutSize",
        "propertyChange",
        "",
        "KgvPageLayout&",
        "layout",
        "setUnit",
        "KgvUnit::Unit",
        "unit",
        "setEnableBorders",
        "on",
        "formatChanged",
        "widthChanged",
        "heightChanged",
        "leftChanged",
        "rightChanged",
        "topChanged",
        "bottomChanged",
        "orientationChanged",
        "setUnitInt"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'propertyChange'
        QtMocHelpers::SignalData<void(KgvPageLayout &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setUnit'
        QtMocHelpers::SlotData<void(KgvUnit::Unit)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'setEnableBorders'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'formatChanged'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'widthChanged'
        QtMocHelpers::SlotData<void(double)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'heightChanged'
        QtMocHelpers::SlotData<void(double)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'leftChanged'
        QtMocHelpers::SlotData<void(double)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'rightChanged'
        QtMocHelpers::SlotData<void(double)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'topChanged'
        QtMocHelpers::SlotData<void(double)>(15, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'bottomChanged'
        QtMocHelpers::SlotData<void(double)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'orientationChanged'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'setUnitInt'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KgvPageLayoutSize, qt_meta_tag_ZN17KgvPageLayoutSizeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KgvPageLayoutSize::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KgvPageLayoutSizeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KgvPageLayoutSizeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17KgvPageLayoutSizeE_t>.metaTypes,
    nullptr
} };

void KgvPageLayoutSize::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KgvPageLayoutSize *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->propertyChange((*reinterpret_cast<std::add_pointer_t<KgvPageLayout&>>(_a[1]))); break;
        case 1: _t->setUnit((*reinterpret_cast<std::add_pointer_t<KgvUnit::Unit>>(_a[1]))); break;
        case 2: _t->setEnableBorders((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->formatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->widthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->heightChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->leftChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 7: _t->rightChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 8: _t->topChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 9: _t->bottomChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->orientationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setUnitInt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KgvPageLayoutSize::*)(KgvPageLayout & )>(_a, &KgvPageLayoutSize::propertyChange, 0))
            return;
    }
}

const QMetaObject *KgvPageLayoutSize::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KgvPageLayoutSize::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KgvPageLayoutSizeE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KgvPageLayoutSize::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KgvPageLayoutSize::propertyChange(KgvPageLayout & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
