/********************************************************************************
** Form generated from reading UI file 'preferencesReopenPreviouslyOpenedFiles.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCESREOPENPREVIOUSLYOPENEDFILES_H
#define UI_PREFERENCESREOPENPREVIOUSLYOPENEDFILES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget
{
public:
    QHBoxLayout *hboxLayout;
    QGroupBox *reopenPreviouslyOpenedFilesMode;
    QVBoxLayout *verticalLayout;
    QRadioButton *yes;
    QRadioButton *no;
    QRadioButton *ask;

    void setupUi(QWidget *KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget)
    {
        if (KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget->objectName().isEmpty())
            KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget->setObjectName("KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget");
        KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget->resize(242, 128);
        hboxLayout = new QHBoxLayout(KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget);
        hboxLayout->setObjectName("hboxLayout");
        reopenPreviouslyOpenedFilesMode = new QGroupBox(KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget);
        reopenPreviouslyOpenedFilesMode->setObjectName("reopenPreviouslyOpenedFilesMode");
        reopenPreviouslyOpenedFilesMode->setChecked(false);
        reopenPreviouslyOpenedFilesMode->setProperty("selectedId", QVariant(-1));
        verticalLayout = new QVBoxLayout(reopenPreviouslyOpenedFilesMode);
        verticalLayout->setObjectName("verticalLayout");
        yes = new QRadioButton(reopenPreviouslyOpenedFilesMode);
        yes->setObjectName("yes");

        verticalLayout->addWidget(yes);

        no = new QRadioButton(reopenPreviouslyOpenedFilesMode);
        no->setObjectName("no");

        verticalLayout->addWidget(no);

        ask = new QRadioButton(reopenPreviouslyOpenedFilesMode);
        ask->setObjectName("ask");

        verticalLayout->addWidget(ask);


        hboxLayout->addWidget(reopenPreviouslyOpenedFilesMode);


        retranslateUi(KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget);

        QMetaObject::connectSlotsByName(KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget);
    } // setupUi

    void retranslateUi(QWidget *KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget)
    {
        reopenPreviouslyOpenedFilesMode->setTitle(tr2i18n("Reopen previously opened files", nullptr));
        yes->setText(tr2i18n("&Yes", nullptr));
        no->setText(tr2i18n("&No", nullptr));
        ask->setText(tr2i18n("As&k", nullptr));
        (void)KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget;
    } // retranslateUi

};

namespace Ui {
    class KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget: public Ui_KGraphViewerPreferencesReopenPreviouslyOpenedFilesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFERENCESREOPENPREVIOUSLYOPENEDFILES_H

