/********************************************************************************
** Form generated from reading UI file 'KgvPageLayoutHeaderBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KGVPAGELAYOUTHEADERBASE_H
#define UI_KGVPAGELAYOUTHEADERBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KgvPageLayoutHeaderBase
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox1;
    QVBoxLayout *vboxLayout1;
    QCheckBox *rhFirst;
    QCheckBox *rhEvenOdd;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacer2;
    QLabel *textLabel3;
    QFrame *headerSpacingPane;
    QGroupBox *groupBox2;
    QVBoxLayout *vboxLayout2;
    QCheckBox *rfFirst;
    QCheckBox *rfEvenOdd;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacer3;
    QLabel *textLabel4;
    QFrame *footerSpacingPane;
    QGroupBox *groupBox3;
    QHBoxLayout *hboxLayout2;
    QSpacerItem *spacer4;
    QLabel *textLabel5;
    QFrame *footnotePane;

    void setupUi(QWidget *KgvPageLayoutHeaderBase)
    {
        if (KgvPageLayoutHeaderBase->objectName().isEmpty())
            KgvPageLayoutHeaderBase->setObjectName("KgvPageLayoutHeaderBase");
        KgvPageLayoutHeaderBase->resize(387, 325);
        vboxLayout = new QVBoxLayout(KgvPageLayoutHeaderBase);
        vboxLayout->setObjectName("vboxLayout");
        groupBox1 = new QGroupBox(KgvPageLayoutHeaderBase);
        groupBox1->setObjectName("groupBox1");
        vboxLayout1 = new QVBoxLayout(groupBox1);
        vboxLayout1->setObjectName("vboxLayout1");
        rhFirst = new QCheckBox(groupBox1);
        rhFirst->setObjectName("rhFirst");

        vboxLayout1->addWidget(rhFirst);

        rhEvenOdd = new QCheckBox(groupBox1);
        rhEvenOdd->setObjectName("rhEvenOdd");

        vboxLayout1->addWidget(rhEvenOdd);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        spacer2 = new QSpacerItem(21, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacer2);

        textLabel3 = new QLabel(groupBox1);
        textLabel3->setObjectName("textLabel3");

        hboxLayout->addWidget(textLabel3);

        headerSpacingPane = new QFrame(groupBox1);
        headerSpacingPane->setObjectName("headerSpacingPane");
        headerSpacingPane->setFrameShape(QFrame::NoFrame);
        headerSpacingPane->setFrameShadow(QFrame::Raised);

        hboxLayout->addWidget(headerSpacingPane);


        vboxLayout1->addLayout(hboxLayout);


        vboxLayout->addWidget(groupBox1);

        groupBox2 = new QGroupBox(KgvPageLayoutHeaderBase);
        groupBox2->setObjectName("groupBox2");
        vboxLayout2 = new QVBoxLayout(groupBox2);
        vboxLayout2->setObjectName("vboxLayout2");
        rfFirst = new QCheckBox(groupBox2);
        rfFirst->setObjectName("rfFirst");

        vboxLayout2->addWidget(rfFirst);

        rfEvenOdd = new QCheckBox(groupBox2);
        rfEvenOdd->setObjectName("rfEvenOdd");

        vboxLayout2->addWidget(rfEvenOdd);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        spacer3 = new QSpacerItem(41, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacer3);

        textLabel4 = new QLabel(groupBox2);
        textLabel4->setObjectName("textLabel4");

        hboxLayout1->addWidget(textLabel4);

        footerSpacingPane = new QFrame(groupBox2);
        footerSpacingPane->setObjectName("footerSpacingPane");
        footerSpacingPane->setFrameShape(QFrame::NoFrame);
        footerSpacingPane->setFrameShadow(QFrame::Raised);

        hboxLayout1->addWidget(footerSpacingPane);


        vboxLayout2->addLayout(hboxLayout1);


        vboxLayout->addWidget(groupBox2);

        groupBox3 = new QGroupBox(KgvPageLayoutHeaderBase);
        groupBox3->setObjectName("groupBox3");
        hboxLayout2 = new QHBoxLayout(groupBox3);
        hboxLayout2->setObjectName("hboxLayout2");
        spacer4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacer4);

        textLabel5 = new QLabel(groupBox3);
        textLabel5->setObjectName("textLabel5");

        hboxLayout2->addWidget(textLabel5);

        footnotePane = new QFrame(groupBox3);
        footnotePane->setObjectName("footnotePane");
        footnotePane->setFrameShape(QFrame::NoFrame);
        footnotePane->setFrameShadow(QFrame::Raised);

        hboxLayout2->addWidget(footnotePane);


        vboxLayout->addWidget(groupBox3);


        retranslateUi(KgvPageLayoutHeaderBase);

        QMetaObject::connectSlotsByName(KgvPageLayoutHeaderBase);
    } // setupUi

    void retranslateUi(QWidget *KgvPageLayoutHeaderBase)
    {
        groupBox1->setTitle(tr2i18n("Header", nullptr));
        rhFirst->setText(tr2i18n("Different header for the first page", nullptr));
        rhEvenOdd->setText(tr2i18n("Different header for even and odd pages", nullptr));
        textLabel3->setText(tr2i18n("Spacing between header and body:", nullptr));
        groupBox2->setTitle(tr2i18n("Footer", nullptr));
        rfFirst->setText(tr2i18n("Different footer for the first page", nullptr));
        rfEvenOdd->setText(tr2i18n("Different footer for even and odd pages", nullptr));
        textLabel4->setText(tr2i18n("Spacing between footer and body:", nullptr));
        groupBox3->setTitle(tr2i18n("Footnote/Endnote", nullptr));
        textLabel5->setText(tr2i18n("Spacing between footnote and body:", nullptr));
        (void)KgvPageLayoutHeaderBase;
    } // retranslateUi

};

namespace Ui {
    class KgvPageLayoutHeaderBase: public Ui_KgvPageLayoutHeaderBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KGVPAGELAYOUTHEADERBASE_H

