/********************************************************************************
** Form generated from reading UI file 'simpleprintingpagesetupbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SIMPLEPRINTINGPAGESETUPBASE_H
#define UI_SIMPLEPRINTINGPAGESETUPBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurllabel.h"

QT_BEGIN_NAMESPACE

class Ui_KGVSimplePrintingPageSetupBase
{
public:
    QVBoxLayout *vboxLayout;
    QVBoxLayout *vboxLayout1;
    QVBoxLayout *vboxLayout2;
    QVBoxLayout *vboxLayout3;
    QVBoxLayout *vboxLayout4;
    QVBoxLayout *vboxLayout5;
    QVBoxLayout *vboxLayout6;
    QLabel *captionLabel;
    QHBoxLayout *hboxLayout;
    QPushButton *printButton;
    QPushButton *printPreviewButton;
    QSpacerItem *spacerItem;
    QLabel *textLabel2;
    QHBoxLayout *hboxLayout1;
    QLineEdit *headerTitleLineEdit;
    QPushButton *headerTitleFontButton;
    QHBoxLayout *hboxLayout2;
    QGroupBox *groupBox1;
    QVBoxLayout *vboxLayout7;
    QLabel *pageSizeAndMarginsLabel;
    QPushButton *changePageSizeAndMarginsButton;
    QGridLayout *gridLayout;
    QCheckBox *addTableBordersCheckbox;
    QCheckBox *addDateTimeCheckbox;
    QSpacerItem *spacerItem1;
    QCheckBox *addPageNumbersCheckbox;
    QGroupBox *groupBox4;
    QVBoxLayout *vboxLayout8;
    QHBoxLayout *hboxLayout3;
    QRadioButton *naturalSizeRadioButton;
    QRadioButton *fitToOnePageRadioButton;
    QRadioButton *fitToSeveralPagesRadioButton;
    QFormLayout *formLayout;
    QLabel *label;
    QSpinBox *horizFitNumInput;
    QLabel *label1;
    QSpinBox *vertFitNumInput;
    QCheckBox *maintainAspectCheckBox;
    QVBoxLayout *vboxLayout9;
    QHBoxLayout *hboxLayout4;
    QLabel *textLabel6;
    KUrlLabel *saveSetupLink;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *KGVSimplePrintingPageSetupBase)
    {
        if (KGVSimplePrintingPageSetupBase->objectName().isEmpty())
            KGVSimplePrintingPageSetupBase->setObjectName("KGVSimplePrintingPageSetupBase");
        KGVSimplePrintingPageSetupBase->resize(804, 805);
        vboxLayout = new QVBoxLayout(KGVSimplePrintingPageSetupBase);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setObjectName("vboxLayout3");
        vboxLayout4 = new QVBoxLayout();
        vboxLayout4->setObjectName("vboxLayout4");
        vboxLayout5 = new QVBoxLayout();
        vboxLayout5->setObjectName("vboxLayout5");
        vboxLayout6 = new QVBoxLayout();
        vboxLayout6->setObjectName("vboxLayout6");
        captionLabel = new QLabel(KGVSimplePrintingPageSetupBase);
        captionLabel->setObjectName("captionLabel");

        vboxLayout6->addWidget(captionLabel);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        printButton = new QPushButton(KGVSimplePrintingPageSetupBase);
        printButton->setObjectName("printButton");

        hboxLayout->addWidget(printButton);

        printPreviewButton = new QPushButton(KGVSimplePrintingPageSetupBase);
        printPreviewButton->setObjectName("printPreviewButton");

        hboxLayout->addWidget(printPreviewButton);

        spacerItem = new QSpacerItem(278, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout6->addLayout(hboxLayout);


        vboxLayout5->addLayout(vboxLayout6);

        textLabel2 = new QLabel(KGVSimplePrintingPageSetupBase);
        textLabel2->setObjectName("textLabel2");

        vboxLayout5->addWidget(textLabel2);


        vboxLayout4->addLayout(vboxLayout5);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(-1, -1, -1, 0);
        headerTitleLineEdit = new QLineEdit(KGVSimplePrintingPageSetupBase);
        headerTitleLineEdit->setObjectName("headerTitleLineEdit");

        hboxLayout1->addWidget(headerTitleLineEdit);

        headerTitleFontButton = new QPushButton(KGVSimplePrintingPageSetupBase);
        headerTitleFontButton->setObjectName("headerTitleFontButton");

        hboxLayout1->addWidget(headerTitleFontButton);


        vboxLayout4->addLayout(hboxLayout1);


        vboxLayout3->addLayout(vboxLayout4);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        groupBox1 = new QGroupBox(KGVSimplePrintingPageSetupBase);
        groupBox1->setObjectName("groupBox1");
        vboxLayout7 = new QVBoxLayout(groupBox1);
        vboxLayout7->setObjectName("vboxLayout7");
        pageSizeAndMarginsLabel = new QLabel(groupBox1);
        pageSizeAndMarginsLabel->setObjectName("pageSizeAndMarginsLabel");

        vboxLayout7->addWidget(pageSizeAndMarginsLabel);


        hboxLayout2->addWidget(groupBox1);

        changePageSizeAndMarginsButton = new QPushButton(KGVSimplePrintingPageSetupBase);
        changePageSizeAndMarginsButton->setObjectName("changePageSizeAndMarginsButton");

        hboxLayout2->addWidget(changePageSizeAndMarginsButton);


        vboxLayout3->addLayout(hboxLayout2);


        vboxLayout2->addLayout(vboxLayout3);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        addTableBordersCheckbox = new QCheckBox(KGVSimplePrintingPageSetupBase);
        addTableBordersCheckbox->setObjectName("addTableBordersCheckbox");

        gridLayout->addWidget(addTableBordersCheckbox, 0, 1, 1, 1);

        addDateTimeCheckbox = new QCheckBox(KGVSimplePrintingPageSetupBase);
        addDateTimeCheckbox->setObjectName("addDateTimeCheckbox");

        gridLayout->addWidget(addDateTimeCheckbox, 1, 0, 1, 1);

        spacerItem1 = new QSpacerItem(91, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem1, 0, 2, 2, 1);

        addPageNumbersCheckbox = new QCheckBox(KGVSimplePrintingPageSetupBase);
        addPageNumbersCheckbox->setObjectName("addPageNumbersCheckbox");

        gridLayout->addWidget(addPageNumbersCheckbox, 0, 0, 1, 1);


        vboxLayout2->addLayout(gridLayout);


        vboxLayout1->addLayout(vboxLayout2);

        groupBox4 = new QGroupBox(KGVSimplePrintingPageSetupBase);
        groupBox4->setObjectName("groupBox4");
        vboxLayout8 = new QVBoxLayout(groupBox4);
        vboxLayout8->setObjectName("vboxLayout8");
        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        naturalSizeRadioButton = new QRadioButton(groupBox4);
        naturalSizeRadioButton->setObjectName("naturalSizeRadioButton");

        hboxLayout3->addWidget(naturalSizeRadioButton);

        fitToOnePageRadioButton = new QRadioButton(groupBox4);
        fitToOnePageRadioButton->setObjectName("fitToOnePageRadioButton");

        hboxLayout3->addWidget(fitToOnePageRadioButton);

        fitToSeveralPagesRadioButton = new QRadioButton(groupBox4);
        fitToSeveralPagesRadioButton->setObjectName("fitToSeveralPagesRadioButton");

        hboxLayout3->addWidget(fitToSeveralPagesRadioButton);


        vboxLayout8->addLayout(hboxLayout3);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(groupBox4);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        horizFitNumInput = new QSpinBox(groupBox4);
        horizFitNumInput->setObjectName("horizFitNumInput");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, horizFitNumInput);

        label1 = new QLabel(groupBox4);
        label1->setObjectName("label1");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label1);

        vertFitNumInput = new QSpinBox(groupBox4);
        vertFitNumInput->setObjectName("vertFitNumInput");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, vertFitNumInput);

        maintainAspectCheckBox = new QCheckBox(groupBox4);
        maintainAspectCheckBox->setObjectName("maintainAspectCheckBox");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, maintainAspectCheckBox);


        vboxLayout8->addLayout(formLayout);


        vboxLayout1->addWidget(groupBox4);

        vboxLayout9 = new QVBoxLayout();
        vboxLayout9->setObjectName("vboxLayout9");
        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setObjectName("hboxLayout4");
        textLabel6 = new QLabel(KGVSimplePrintingPageSetupBase);
        textLabel6->setObjectName("textLabel6");

        hboxLayout4->addWidget(textLabel6);


        vboxLayout9->addLayout(hboxLayout4);

        saveSetupLink = new KUrlLabel(KGVSimplePrintingPageSetupBase);
        saveSetupLink->setObjectName("saveSetupLink");

        vboxLayout9->addWidget(saveSetupLink);


        vboxLayout1->addLayout(vboxLayout9);

        buttonBox = new QDialogButtonBox(KGVSimplePrintingPageSetupBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        vboxLayout1->addWidget(buttonBox);


        vboxLayout->addLayout(vboxLayout1);

#if QT_CONFIG(shortcut)
        captionLabel->setBuddy(headerTitleLineEdit);
        textLabel2->setBuddy(headerTitleLineEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(printButton, printPreviewButton);
        QWidget::setTabOrder(printPreviewButton, headerTitleFontButton);
        QWidget::setTabOrder(headerTitleFontButton, changePageSizeAndMarginsButton);
        QWidget::setTabOrder(changePageSizeAndMarginsButton, addPageNumbersCheckbox);
        QWidget::setTabOrder(addPageNumbersCheckbox, addTableBordersCheckbox);
        QWidget::setTabOrder(addTableBordersCheckbox, addDateTimeCheckbox);
        QWidget::setTabOrder(addDateTimeCheckbox, naturalSizeRadioButton);
        QWidget::setTabOrder(naturalSizeRadioButton, fitToOnePageRadioButton);
        QWidget::setTabOrder(fitToOnePageRadioButton, fitToSeveralPagesRadioButton);
        QWidget::setTabOrder(fitToSeveralPagesRadioButton, horizFitNumInput);
        QWidget::setTabOrder(horizFitNumInput, vertFitNumInput);
        QWidget::setTabOrder(vertFitNumInput, maintainAspectCheckBox);
        QWidget::setTabOrder(maintainAspectCheckBox, saveSetupLink);
        QWidget::setTabOrder(saveSetupLink, headerTitleLineEdit);

        retranslateUi(KGVSimplePrintingPageSetupBase);

        QMetaObject::connectSlotsByName(KGVSimplePrintingPageSetupBase);
    } // setupUi

    void retranslateUi(QWidget *KGVSimplePrintingPageSetupBase)
    {
        textLabel2->setText(tr2i18n("Pa&ge font:", nullptr));
        groupBox1->setTitle(tr2i18n("Page Size && Margins", nullptr));
        pageSizeAndMarginsLabel->setText(QString());
        addTableBordersCheckbox->setText(tr2i18n("Add &borders", nullptr));
        addDateTimeCheckbox->setText(tr2i18n("Add date and time", nullptr));
        addPageNumbersCheckbox->setText(tr2i18n("Add page numbers", nullptr));
        groupBox4->setTitle(tr2i18n("Number of pages to fit on", nullptr));
        naturalSizeRadioButton->setText(tr2i18n("&Natural size", nullptr));
        fitToOnePageRadioButton->setText(tr2i18n("Fit &to one page", nullptr));
        fitToSeveralPagesRadioButton->setText(tr2i18n("F&it to several pages", nullptr));
        label->setText(tr2i18n("Horizontally:", "@label:spinbox"));
        label1->setText(tr2i18n("Vertically:", "@label:spinbox"));
        maintainAspectCheckBox->setText(tr2i18n("Preserve aspect ratio:", "@option:check"));
        textLabel6->setText(tr2i18n("Related actions:", nullptr));
        (void)KGVSimplePrintingPageSetupBase;
    } // retranslateUi

};

namespace Ui {
    class KGVSimplePrintingPageSetupBase: public Ui_KGVSimplePrintingPageSetupBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SIMPLEPRINTINGPAGESETUPBASE_H

