// This file is generated by kconfig_compiler_kf6 from kgraphviewer_partsettings.kcfg.
// All changes you do to this file will be lost.
#ifndef KGRAPHVIEWERPARTSETTINGS_H
#define KGRAPHVIEWERPARTSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class KGraphViewerPartSettings : public KConfigSkeleton
{
  public:

    static KGraphViewerPartSettings *self();
    ~KGraphViewerPartSettings() override;

    /**
      Set If true, the bird's eye view will be shown if needed.
    */
    static
    void setBirdsEyeViewEnabled( bool v )
    {
      if (!self()->isBirdsEyeViewEnabledImmutable())
        self()->mBirdsEyeViewEnabled = v;
    }

    /**
      Get If true, the bird's eye view will be shown if needed.
    */
    static
    bool birdsEyeViewEnabled()
    {
      return self()->mBirdsEyeViewEnabled;
    }

    /**
      Is If true, the bird's eye view will be shown if needed. Immutable
    */
    static
    bool isBirdsEyeViewEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "birdsEyeViewEnabled" ) );
    }

  protected:
    KGraphViewerPartSettings();
    friend class KGraphViewerPartSettingsHelper;


    // Notification Messages
    bool mBirdsEyeViewEnabled;
};

#endif

