/********************************************************************************
** Form generated from reading UI file 'preferencesReload.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCESRELOAD_H
#define UI_PREFERENCESRELOAD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KGraphViewerPreferencesReloadWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *reloadOnChangeMode;
    QVBoxLayout *verticalLayout;
    QRadioButton *yes;
    QRadioButton *no;
    QRadioButton *ask;

    void setupUi(QWidget *KGraphViewerPreferencesReloadWidget)
    {
        if (KGraphViewerPreferencesReloadWidget->objectName().isEmpty())
            KGraphViewerPreferencesReloadWidget->setObjectName("KGraphViewerPreferencesReloadWidget");
        KGraphViewerPreferencesReloadWidget->resize(225, 128);
        gridLayout = new QGridLayout(KGraphViewerPreferencesReloadWidget);
        gridLayout->setObjectName("gridLayout");
        reloadOnChangeMode = new QGroupBox(KGraphViewerPreferencesReloadWidget);
        reloadOnChangeMode->setObjectName("reloadOnChangeMode");
        reloadOnChangeMode->setProperty("selectedId", QVariant(2));
        verticalLayout = new QVBoxLayout(reloadOnChangeMode);
        verticalLayout->setObjectName("verticalLayout");
        yes = new QRadioButton(reloadOnChangeMode);
        yes->setObjectName("yes");

        verticalLayout->addWidget(yes);

        no = new QRadioButton(reloadOnChangeMode);
        no->setObjectName("no");

        verticalLayout->addWidget(no);

        ask = new QRadioButton(reloadOnChangeMode);
        ask->setObjectName("ask");

        verticalLayout->addWidget(ask);


        gridLayout->addWidget(reloadOnChangeMode, 0, 0, 1, 1);


        retranslateUi(KGraphViewerPreferencesReloadWidget);

        QMetaObject::connectSlotsByName(KGraphViewerPreferencesReloadWidget);
    } // setupUi

    void retranslateUi(QWidget *KGraphViewerPreferencesReloadWidget)
    {
        reloadOnChangeMode->setTitle(tr2i18n("Reload files modified on disk", nullptr));
        yes->setText(tr2i18n("&Yes", nullptr));
        no->setText(tr2i18n("&No", nullptr));
        ask->setText(tr2i18n("&Ask", nullptr));
        (void)KGraphViewerPreferencesReloadWidget;
    } // retranslateUi

};

namespace Ui {
    class KGraphViewerPreferencesReloadWidget: public Ui_KGraphViewerPreferencesReloadWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFERENCESRELOAD_H

