/****************************************************************************
** Meta object code from reading C++ file 'dotgraphview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kgraphviewer-26.04.3/src/part/dotgraphview.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dotgraphview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KGraphViewer12DotGraphViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KGraphViewer::DotGraphView::qt_create_metaobjectdata<qt_meta_tag_ZN12KGraphViewer12DotGraphViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGraphViewer::DotGraphView",
        "zoomed",
        "",
        "factor",
        "sigViewBevEnabledToggled",
        "value",
        "sigViewBevActivated",
        "newPos",
        "graphLoaded",
        "newNodeAdded",
        "newEdgeAdded",
        "removeEdge",
        "removeNodeNamed",
        "removeElement",
        "selectionIs",
        "QPoint",
        "newEdgeFinished",
        "QMap<QString,QString>",
        "contextMenuEvent",
        "hoverEnter",
        "hoverLeave",
        "zoomIn",
        "zoomOut",
        "zoomRectMovedTo",
        "QPointF",
        "newZoomPos",
        "zoomRectMoveFinished",
        "initEmpty",
        "slotLoadLibrary",
        "graph_t*",
        "graph",
        "reload",
        "dirty",
        "dotFileName",
        "pageSetup",
        "print",
        "printPreview",
        "viewBevActivated",
        "slotExportImage",
        "slotSelectLayoutAlgo",
        "text",
        "slotLayoutSpecify",
        "slotLayoutReset",
        "slotSelectLayoutDot",
        "slotSelectLayoutNeato",
        "slotSelectLayoutTwopi",
        "slotSelectLayoutFdp",
        "slotSelectLayoutCirco",
        "slotBevToggled",
        "slotBevTopLeft",
        "slotBevTopRight",
        "slotBevBottomLeft",
        "slotBevBottomRight",
        "slotBevAutomatic",
        "slotUpdate",
        "displayGraph",
        "slotEdgeSelected",
        "CanvasEdge*",
        "Qt::KeyboardModifiers",
        "slotElementSelected",
        "CanvasElement*",
        "slotSelectionChanged",
        "slotContextMenuEvent",
        "slotElementHoverEnter",
        "slotElementHoverLeave",
        "slotSelectNode",
        "nodeName",
        "centerOnNode",
        "nodeId",
        "slotAGraphReadFinished",
        "slotAGraphLayoutFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'zoomed'
        QtMocHelpers::SignalData<void(double)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Signal 'sigViewBevEnabledToggled'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'sigViewBevActivated'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'graphLoaded'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newNodeAdded'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'newEdgeAdded'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'removeEdge'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'removeNodeNamed'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'removeElement'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'selectionIs'
        QtMocHelpers::SignalData<void(const QList<QString>, const QPoint &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Signal 'newEdgeFinished'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QMap<QString,QString> &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { 0x80000000 | 17, 2 },
        }}),
        // Signal 'contextMenuEvent'
        QtMocHelpers::SignalData<void(const QString &, const QPoint &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Signal 'hoverEnter'
        QtMocHelpers::SignalData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'hoverLeave'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomRectMovedTo'
        QtMocHelpers::SlotData<void(QPointF)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'zoomRectMoveFinished'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'initEmpty'
        QtMocHelpers::SlotData<bool()>(27, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotLoadLibrary'
        QtMocHelpers::SlotData<bool(graph_t *)>(28, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'reload'
        QtMocHelpers::SlotData<bool()>(31, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'dirty'
        QtMocHelpers::SlotData<void(const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 },
        }}),
        // Slot 'pageSetup'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'print'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'printPreview'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'viewBevActivated'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'slotExportImage'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectLayoutAlgo'
        QtMocHelpers::SlotData<void(const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'slotLayoutSpecify'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLayoutReset'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectLayoutDot'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectLayoutNeato'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectLayoutTwopi'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectLayoutFdp'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectLayoutCirco'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBevToggled'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBevTopLeft'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBevTopRight'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBevBottomLeft'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBevBottomRight'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBevAutomatic'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdate'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'displayGraph'
        QtMocHelpers::SlotData<bool()>(55, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotEdgeSelected'
        QtMocHelpers::SlotData<void(CanvasEdge *, Qt::KeyboardModifiers)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 57, 2 }, { 0x80000000 | 58, 2 },
        }}),
        // Slot 'slotElementSelected'
        QtMocHelpers::SlotData<void(CanvasElement *, Qt::KeyboardModifiers)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 60, 2 }, { 0x80000000 | 58, 2 },
        }}),
        // Slot 'slotSelectionChanged'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotContextMenuEvent'
        QtMocHelpers::SlotData<void(const QString &, const QPoint &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Slot 'slotElementHoverEnter'
        QtMocHelpers::SlotData<void(CanvasElement *)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 60, 2 },
        }}),
        // Slot 'slotElementHoverLeave'
        QtMocHelpers::SlotData<void(CanvasElement *)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 60, 2 },
        }}),
        // Slot 'slotElementHoverEnter'
        QtMocHelpers::SlotData<void(CanvasEdge *)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 57, 2 },
        }}),
        // Slot 'slotElementHoverLeave'
        QtMocHelpers::SlotData<void(CanvasEdge *)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 57, 2 },
        }}),
        // Slot 'slotSelectNode'
        QtMocHelpers::SlotData<void(const QString &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 66 },
        }}),
        // Slot 'centerOnNode'
        QtMocHelpers::SlotData<void(const QString &)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 68 },
        }}),
        // Slot 'slotAGraphReadFinished'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAGraphLayoutFinished'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DotGraphView, qt_meta_tag_ZN12KGraphViewer12DotGraphViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGraphViewer::DotGraphView::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer12DotGraphViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer12DotGraphViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KGraphViewer12DotGraphViewE_t>.metaTypes,
    nullptr
} };

void KGraphViewer::DotGraphView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DotGraphView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->zoomed((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 1: _t->sigViewBevEnabledToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->sigViewBevActivated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->graphLoaded(); break;
        case 4: _t->newNodeAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->newEdgeAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->removeEdge((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->removeNodeNamed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->removeElement((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->selectionIs((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 10: _t->newEdgeFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[3]))); break;
        case 11: _t->contextMenuEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 12: _t->hoverEnter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->hoverLeave((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->zoomIn(); break;
        case 15: _t->zoomOut(); break;
        case 16: _t->zoomRectMovedTo((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 17: _t->zoomRectMoveFinished(); break;
        case 18: { bool _r = _t->initEmpty();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->slotLoadLibrary((*reinterpret_cast<std::add_pointer_t<graph_t*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->reload();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->dirty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->pageSetup(); break;
        case 23: _t->print(); break;
        case 24: _t->printPreview(); break;
        case 25: _t->viewBevActivated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->slotExportImage(); break;
        case 27: _t->slotSelectLayoutAlgo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->slotLayoutSpecify(); break;
        case 29: _t->slotLayoutReset(); break;
        case 30: _t->slotSelectLayoutDot(); break;
        case 31: _t->slotSelectLayoutNeato(); break;
        case 32: _t->slotSelectLayoutTwopi(); break;
        case 33: _t->slotSelectLayoutFdp(); break;
        case 34: _t->slotSelectLayoutCirco(); break;
        case 35: _t->slotBevToggled(); break;
        case 36: _t->slotBevTopLeft(); break;
        case 37: _t->slotBevTopRight(); break;
        case 38: _t->slotBevBottomLeft(); break;
        case 39: _t->slotBevBottomRight(); break;
        case 40: _t->slotBevAutomatic(); break;
        case 41: _t->slotUpdate(); break;
        case 42: { bool _r = _t->displayGraph();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->slotEdgeSelected((*reinterpret_cast<std::add_pointer_t<CanvasEdge*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::KeyboardModifiers>>(_a[2]))); break;
        case 44: _t->slotElementSelected((*reinterpret_cast<std::add_pointer_t<CanvasElement*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::KeyboardModifiers>>(_a[2]))); break;
        case 45: _t->slotSelectionChanged(); break;
        case 46: _t->slotContextMenuEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 47: _t->slotElementHoverEnter((*reinterpret_cast<std::add_pointer_t<CanvasElement*>>(_a[1]))); break;
        case 48: _t->slotElementHoverLeave((*reinterpret_cast<std::add_pointer_t<CanvasElement*>>(_a[1]))); break;
        case 49: _t->slotElementHoverEnter((*reinterpret_cast<std::add_pointer_t<CanvasEdge*>>(_a[1]))); break;
        case 50: _t->slotElementHoverLeave((*reinterpret_cast<std::add_pointer_t<CanvasEdge*>>(_a[1]))); break;
        case 51: _t->slotSelectNode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 52: _t->centerOnNode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 53: _t->slotAGraphReadFinished(); break;
        case 54: _t->slotAGraphLayoutFinished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(double )>(_a, &DotGraphView::zoomed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(bool )>(_a, &DotGraphView::sigViewBevEnabledToggled, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(int )>(_a, &DotGraphView::sigViewBevActivated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)()>(_a, &DotGraphView::graphLoaded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(const QString & )>(_a, &DotGraphView::newNodeAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(const QString & , const QString & )>(_a, &DotGraphView::newEdgeAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(const QString & )>(_a, &DotGraphView::removeEdge, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(const QString & )>(_a, &DotGraphView::removeNodeNamed, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(const QString & )>(_a, &DotGraphView::removeElement, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(const QList<QString> , const QPoint & )>(_a, &DotGraphView::selectionIs, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(const QString & , const QString & , const QMap<QString,QString> & )>(_a, &DotGraphView::newEdgeFinished, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(const QString & , const QPoint & )>(_a, &DotGraphView::contextMenuEvent, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(const QString & )>(_a, &DotGraphView::hoverEnter, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DotGraphView::*)(const QString & )>(_a, &DotGraphView::hoverLeave, 13))
            return;
    }
}

const QMetaObject *KGraphViewer::DotGraphView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGraphViewer::DotGraphView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer12DotGraphViewE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int KGraphViewer::DotGraphView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 55)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 55;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 55)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 55;
    }
    return _id;
}

// SIGNAL 0
void KGraphViewer::DotGraphView::zoomed(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KGraphViewer::DotGraphView::sigViewBevEnabledToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KGraphViewer::DotGraphView::sigViewBevActivated(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KGraphViewer::DotGraphView::graphLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KGraphViewer::DotGraphView::newNodeAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KGraphViewer::DotGraphView::newEdgeAdded(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KGraphViewer::DotGraphView::removeEdge(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KGraphViewer::DotGraphView::removeNodeNamed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KGraphViewer::DotGraphView::removeElement(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KGraphViewer::DotGraphView::selectionIs(const QList<QString> _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void KGraphViewer::DotGraphView::newEdgeFinished(const QString & _t1, const QString & _t2, const QMap<QString,QString> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3);
}

// SIGNAL 11
void KGraphViewer::DotGraphView::contextMenuEvent(const QString & _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void KGraphViewer::DotGraphView::hoverEnter(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void KGraphViewer::DotGraphView::hoverLeave(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
