/********************************************************************************
** Form generated from reading UI file 'preferencesOpenInExistingWindow.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCESOPENINEXISTINGWINDOW_H
#define UI_PREFERENCESOPENINEXISTINGWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KGraphViewerPreferencesOpenInExistingWindowWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *openInExistingWindowMode;
    QVBoxLayout *verticalLayout;
    QRadioButton *yes;
    QRadioButton *no;
    QRadioButton *ask;

    void setupUi(QWidget *KGraphViewerPreferencesOpenInExistingWindowWidget)
    {
        if (KGraphViewerPreferencesOpenInExistingWindowWidget->objectName().isEmpty())
            KGraphViewerPreferencesOpenInExistingWindowWidget->setObjectName("KGraphViewerPreferencesOpenInExistingWindowWidget");
        KGraphViewerPreferencesOpenInExistingWindowWidget->resize(197, 128);
        gridLayout = new QGridLayout(KGraphViewerPreferencesOpenInExistingWindowWidget);
        gridLayout->setObjectName("gridLayout");
        openInExistingWindowMode = new QGroupBox(KGraphViewerPreferencesOpenInExistingWindowWidget);
        openInExistingWindowMode->setObjectName("openInExistingWindowMode");
        verticalLayout = new QVBoxLayout(openInExistingWindowMode);
        verticalLayout->setObjectName("verticalLayout");
        yes = new QRadioButton(openInExistingWindowMode);
        yes->setObjectName("yes");

        verticalLayout->addWidget(yes);

        no = new QRadioButton(openInExistingWindowMode);
        no->setObjectName("no");

        verticalLayout->addWidget(no);

        ask = new QRadioButton(openInExistingWindowMode);
        ask->setObjectName("ask");

        verticalLayout->addWidget(ask);


        gridLayout->addWidget(openInExistingWindowMode, 0, 0, 1, 1);


        retranslateUi(KGraphViewerPreferencesOpenInExistingWindowWidget);

        QMetaObject::connectSlotsByName(KGraphViewerPreferencesOpenInExistingWindowWidget);
    } // setupUi

    void retranslateUi(QWidget *KGraphViewerPreferencesOpenInExistingWindowWidget)
    {
        openInExistingWindowMode->setTitle(tr2i18n("Open in existing window", nullptr));
        yes->setText(tr2i18n("&Yes", nullptr));
        no->setText(tr2i18n("&No", nullptr));
        ask->setText(tr2i18n("As&k", nullptr));
        (void)KGraphViewerPreferencesOpenInExistingWindowWidget;
    } // retranslateUi

};

namespace Ui {
    class KGraphViewerPreferencesOpenInExistingWindowWidget: public Ui_KGraphViewerPreferencesOpenInExistingWindowWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFERENCESOPENINEXISTINGWINDOW_H

