// This file is generated by kconfig_compiler_kf6 from kgraphviewer_partsettings.kcfg.
// All changes you do to this file will be lost.

#include "kgraphviewer_partsettings.h"

#include <qglobal.h>
#include <QFile>

class KGraphViewerPartSettingsHelper
{
  public:
    KGraphViewerPartSettingsHelper() noexcept : q(nullptr) {}
    ~KGraphViewerPartSettingsHelper() noexcept { delete q; q = nullptr; }
    KGraphViewerPartSettingsHelper(const KGraphViewerPartSettingsHelper&) = delete;
    KGraphViewerPartSettingsHelper& operator=(const KGraphViewerPartSettingsHelper&) = delete;
    KGraphViewerPartSettings *q;
};
Q_GLOBAL_STATIC(KGraphViewerPartSettingsHelper, s_globalKGraphViewerPartSettings)
KGraphViewerPartSettings *KGraphViewerPartSettings::self()
{
  if (!s_globalKGraphViewerPartSettings()->q) {
    new KGraphViewerPartSettings;
    s_globalKGraphViewerPartSettings()->q->read();
  }

  return s_globalKGraphViewerPartSettings()->q;
}

KGraphViewerPartSettings::KGraphViewerPartSettings( )
  : KConfigSkeleton( QStringLiteral( "kgraphviewer_partrc" ) )
{
  Q_ASSERT(!s_globalKGraphViewerPartSettings()->q);
  s_globalKGraphViewerPartSettings()->q = this;
  setCurrentGroup( QStringLiteral( "Notification Messages" ) );

  KConfigSkeleton::ItemBool  *itemBirdsEyeViewEnabled;
  itemBirdsEyeViewEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "birdsEyeViewEnabled" ), mBirdsEyeViewEnabled, true );
  addItem( itemBirdsEyeViewEnabled, QStringLiteral( "birdsEyeViewEnabled" ) );
}

KGraphViewerPartSettings::~KGraphViewerPartSettings()
{
  if (s_globalKGraphViewerPartSettings.exists() && !s_globalKGraphViewerPartSettings.isDestroyed()) {
    s_globalKGraphViewerPartSettings()->q = nullptr;
  }
}

