/********************************************************************************
** Form generated from reading UI file 'preferencesParsing.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCESPARSING_H
#define UI_PREFERENCESPARSING_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KGraphViewerPreferencesParsingWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *parsingMode;
    QVBoxLayout *verticalLayout;
    QRadioButton *external;
    QRadioButton *internal;

    void setupUi(QWidget *KGraphViewerPreferencesParsingWidget)
    {
        if (KGraphViewerPreferencesParsingWidget->objectName().isEmpty())
            KGraphViewerPreferencesParsingWidget->setObjectName("KGraphViewerPreferencesParsingWidget");
        KGraphViewerPreferencesParsingWidget->resize(188, 104);
        gridLayout = new QGridLayout(KGraphViewerPreferencesParsingWidget);
        gridLayout->setObjectName("gridLayout");
        parsingMode = new QGroupBox(KGraphViewerPreferencesParsingWidget);
        parsingMode->setObjectName("parsingMode");
        parsingMode->setProperty("selectedId", QVariant(2));
        verticalLayout = new QVBoxLayout(parsingMode);
        verticalLayout->setObjectName("verticalLayout");
        external = new QRadioButton(parsingMode);
        external->setObjectName("external");

        verticalLayout->addWidget(external);

        internal = new QRadioButton(parsingMode);
        internal->setObjectName("internal");

        verticalLayout->addWidget(internal);


        gridLayout->addWidget(parsingMode, 0, 0, 1, 1);


        retranslateUi(KGraphViewerPreferencesParsingWidget);

        QMetaObject::connectSlotsByName(KGraphViewerPreferencesParsingWidget);
    } // setupUi

    void retranslateUi(QWidget *KGraphViewerPreferencesParsingWidget)
    {
        parsingMode->setTitle(tr2i18n("Parse using:", nullptr));
        external->setText(tr2i18n("E&xternal command", nullptr));
        internal->setText(tr2i18n("Internal &library", nullptr));
        (void)KGraphViewerPreferencesParsingWidget;
    } // retranslateUi

};

namespace Ui {
    class KGraphViewerPreferencesParsingWidget: public Ui_KGraphViewerPreferencesParsingWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFERENCESPARSING_H

