/****************************************************************************
** Meta object code from reading C++ file 'simpleprintingpagesetup.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kgraphviewer-26.04.3/src/part/simpleprintingpagesetup.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'simpleprintingpagesetup.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KGraphViewer26KGVSimplePrintingPageSetupE_t {};
} // unnamed namespace

template <> constexpr inline auto KGraphViewer::KGVSimplePrintingPageSetup::qt_create_metaobjectdata<qt_meta_tag_ZN12KGraphViewer26KGVSimplePrintingPageSetupE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGraphViewer::KGVSimplePrintingPageSetup",
        "print",
        "",
        "KGVSimplePrintingSettings*",
        "settings",
        "titleText",
        "printPreview",
        "reload",
        "needsRedraw",
        "slotPrint",
        "slotPrintPreview",
        "slotSaveSetup",
        "slotChangeTitleFont",
        "slotChangePageSizeAndMargins",
        "slotAddPageNumbersCheckboxToggled",
        "set",
        "slotAddDateTimeCheckboxToggled",
        "slotAddTableBordersCheckboxToggled",
        "slotTitleTextChanged",
        "slotClose",
        "slotFittingButtonClicked",
        "id",
        "slotHorizFitChanged",
        "newValue",
        "slotVertFitChanged",
        "slotMaintainAspectCheckBoxToggled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'print'
        QtMocHelpers::SignalData<void(KGVSimplePrintingSettings *, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'printPreview'
        QtMocHelpers::SignalData<void(KGVSimplePrintingSettings *, const QString &, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'print'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'printPreview'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'needsRedraw'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPrint'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPrintPreview'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveSetup'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotChangeTitleFont'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotChangePageSizeAndMargins'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotAddPageNumbersCheckboxToggled'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'slotAddDateTimeCheckboxToggled'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'slotAddTableBordersCheckboxToggled'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'slotTitleTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotClose'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotFittingButtonClicked'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'slotHorizFitChanged'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'slotVertFitChanged'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'slotMaintainAspectCheckBoxToggled'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGVSimplePrintingPageSetup, qt_meta_tag_ZN12KGraphViewer26KGVSimplePrintingPageSetupE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGraphViewer::KGVSimplePrintingPageSetup::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer26KGVSimplePrintingPageSetupE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer26KGVSimplePrintingPageSetupE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KGraphViewer26KGVSimplePrintingPageSetupE_t>.metaTypes,
    nullptr
} };

void KGraphViewer::KGVSimplePrintingPageSetup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGVSimplePrintingPageSetup *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->print((*reinterpret_cast<std::add_pointer_t<KGVSimplePrintingSettings*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->printPreview((*reinterpret_cast<std::add_pointer_t<KGVSimplePrintingSettings*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 2: _t->print(); break;
        case 3: _t->printPreview(); break;
        case 4: _t->needsRedraw(); break;
        case 5: _t->slotPrint(); break;
        case 6: _t->slotPrintPreview(); break;
        case 7: _t->slotSaveSetup(); break;
        case 8: _t->slotChangeTitleFont(); break;
        case 9: _t->slotChangePageSizeAndMargins(); break;
        case 10: _t->slotAddPageNumbersCheckboxToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->slotAddDateTimeCheckboxToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->slotAddTableBordersCheckboxToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->slotTitleTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->slotClose(); break;
        case 15: _t->slotFittingButtonClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->slotHorizFitChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->slotVertFitChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->slotMaintainAspectCheckBoxToggled(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KGVSimplePrintingPageSetup::*)(KGVSimplePrintingSettings * , const QString & )>(_a, &KGVSimplePrintingPageSetup::print, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGVSimplePrintingPageSetup::*)(KGVSimplePrintingSettings * , const QString & , bool )>(_a, &KGVSimplePrintingPageSetup::printPreview, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGVSimplePrintingPageSetup::*)()>(_a, &KGVSimplePrintingPageSetup::print, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGVSimplePrintingPageSetup::*)()>(_a, &KGVSimplePrintingPageSetup::printPreview, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGVSimplePrintingPageSetup::*)()>(_a, &KGVSimplePrintingPageSetup::needsRedraw, 4))
            return;
    }
}

const QMetaObject *KGraphViewer::KGVSimplePrintingPageSetup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGraphViewer::KGVSimplePrintingPageSetup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer26KGVSimplePrintingPageSetupE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KGraphViewer::KGVSimplePrintingPageSetup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void KGraphViewer::KGVSimplePrintingPageSetup::print(KGVSimplePrintingSettings * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KGraphViewer::KGVSimplePrintingPageSetup::printPreview(KGVSimplePrintingSettings * _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void KGraphViewer::KGVSimplePrintingPageSetup::print()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KGraphViewer::KGVSimplePrintingPageSetup::printPreview()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KGraphViewer::KGVSimplePrintingPageSetup::needsRedraw()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
