/****************************************************************************
** Meta object code from reading C++ file 'simpleprintpreviewwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kgraphviewer-26.04.3/src/part/simpleprintpreviewwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'simpleprintpreviewwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KGraphViewer27KGVSimplePrintPreviewWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto KGraphViewer::KGVSimplePrintPreviewWindow::qt_create_metaobjectdata<qt_meta_tag_ZN12KGraphViewer27KGVSimplePrintPreviewWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGraphViewer::KGVSimplePrintPreviewWindow",
        "printRequested",
        "",
        "pageSetupRequested",
        "updatePagesCount",
        "goToPage",
        "pageNumber",
        "setFullWidth",
        "slotRedraw",
        "slotPageSetup",
        "slotPrintClicked",
        "slotZoomInClicked",
        "slotZoomOutClicked",
        "slotFirstClicked",
        "slotPreviousClicked",
        "slotNextClicked",
        "slotLastClicked",
        "initLater"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'printRequested'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pageSetupRequested'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updatePagesCount'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goToPage'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'setFullWidth'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRedraw'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPageSetup'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotPrintClicked'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotZoomInClicked'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotZoomOutClicked'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotFirstClicked'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotPreviousClicked'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotNextClicked'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotLastClicked'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'initLater'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGVSimplePrintPreviewWindow, qt_meta_tag_ZN12KGraphViewer27KGVSimplePrintPreviewWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGraphViewer::KGVSimplePrintPreviewWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer27KGVSimplePrintPreviewWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer27KGVSimplePrintPreviewWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KGraphViewer27KGVSimplePrintPreviewWindowE_t>.metaTypes,
    nullptr
} };

void KGraphViewer::KGVSimplePrintPreviewWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGVSimplePrintPreviewWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->printRequested(); break;
        case 1: _t->pageSetupRequested(); break;
        case 2: _t->updatePagesCount(); break;
        case 3: _t->goToPage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->setFullWidth(); break;
        case 5: _t->slotRedraw(); break;
        case 6: _t->slotPageSetup(); break;
        case 7: _t->slotPrintClicked(); break;
        case 8: _t->slotZoomInClicked(); break;
        case 9: _t->slotZoomOutClicked(); break;
        case 10: _t->slotFirstClicked(); break;
        case 11: _t->slotPreviousClicked(); break;
        case 12: _t->slotNextClicked(); break;
        case 13: _t->slotLastClicked(); break;
        case 14: _t->initLater(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KGVSimplePrintPreviewWindow::*)()>(_a, &KGVSimplePrintPreviewWindow::printRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGVSimplePrintPreviewWindow::*)()>(_a, &KGVSimplePrintPreviewWindow::pageSetupRequested, 1))
            return;
    }
}

const QMetaObject *KGraphViewer::KGVSimplePrintPreviewWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGraphViewer::KGVSimplePrintPreviewWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer27KGVSimplePrintPreviewWindowE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KGraphViewer::KGVSimplePrintPreviewWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void KGraphViewer::KGVSimplePrintPreviewWindow::printRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KGraphViewer::KGVSimplePrintPreviewWindow::pageSetupRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
