/****************************************************************************
** Meta object code from reading C++ file 'kgraphviewer_part.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kgraphviewer-26.04.3/src/part/kgraphviewer_part.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgraphviewer_part.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KGraphViewer16KGraphViewerPartE_t {};
} // unnamed namespace

template <> constexpr inline auto KGraphViewer::KGraphViewerPart::qt_create_metaobjectdata<qt_meta_tag_ZN12KGraphViewer16KGraphViewerPartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGraphViewer::KGraphViewerPart",
        "graphLoaded",
        "",
        "newNodeAdded",
        "newEdgeAdded",
        "removeEdge",
        "removeElement",
        "selectionIs",
        "QPoint",
        "contextMenuEvent",
        "newEdgeFinished",
        "QMap<QString,QString>",
        "hoverEnter",
        "hoverLeave",
        "slotHide",
        "KParts::Part*",
        "part",
        "slotUpdate",
        "prepareAddNewElement",
        "attribs",
        "prepareAddNewEdge",
        "setReadOnly",
        "setReadWrite",
        "saveTo",
        "fileName",
        "slotRemoveNode",
        "slotRemoveNodeFromSubgraph",
        "nodeName",
        "subgraphName",
        "slotRemoveSubgraph",
        "slotAddAttribute",
        "slotSetAttribute",
        "elementId",
        "attributeName",
        "attributeValue",
        "slotRemoveAttribute",
        "slotSetGraphAttributes",
        "slotAddNewNode",
        "slotAddNewNodeToSubgraph",
        "subgraph",
        "slotAddExistingNodeToSubgraph",
        "slotMoveExistingNodeToMainGraph",
        "slotAddNewSubgraph",
        "slotAddNewEdge",
        "src",
        "tgt",
        "slotRemoveEdge",
        "id",
        "slotRemoveElement",
        "slotSelectNode",
        "slotSetHighlighting",
        "highlightingValue",
        "slotPrepareToSelect",
        "slotSetCursor",
        "QCursor",
        "cursor",
        "slotUnsetCursor",
        "closeUrl",
        "slotLoadLibrary",
        "graph_t*",
        "graph",
        "slotSetLayoutMethod",
        "LayoutMethod",
        "method",
        "slotRenameNode",
        "oldNodeName",
        "newNodeName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'graphLoaded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newNodeAdded'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'newEdgeAdded'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'removeEdge'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'removeElement'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'selectionIs'
        QtMocHelpers::SignalData<void(const QList<QString>, const QPoint &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 }, { 0x80000000 | 8, 2 },
        }}),
        // Signal 'contextMenuEvent'
        QtMocHelpers::SignalData<void(const QString &, const QPoint &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 8, 2 },
        }}),
        // Signal 'newEdgeFinished'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QMap<QString,QString> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { 0x80000000 | 11, 2 },
        }}),
        // Signal 'hoverEnter'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'hoverLeave'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotHide'
        QtMocHelpers::SlotData<void(KParts::Part *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotUpdate'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'prepareAddNewElement'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 19 },
        }}),
        // Slot 'prepareAddNewEdge'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 19 },
        }}),
        // Slot 'setReadOnly'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setReadWrite'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveTo'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'slotRemoveNode'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotRemoveNodeFromSubgraph'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 28 },
        }}),
        // Slot 'slotRemoveSubgraph'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotAddAttribute'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotSetAttribute'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 33 }, { QMetaType::QString, 34 },
        }}),
        // Slot 'slotRemoveAttribute'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'slotSetGraphAttributes'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 19 },
        }}),
        // Slot 'slotAddNewNode'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 19 },
        }}),
        // Slot 'slotAddNewNodeToSubgraph'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &, const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 19 }, { QMetaType::QString, 39 },
        }}),
        // Slot 'slotAddExistingNodeToSubgraph'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &, const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 19 }, { QMetaType::QString, 39 },
        }}),
        // Slot 'slotMoveExistingNodeToMainGraph'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 19 },
        }}),
        // Slot 'slotAddNewSubgraph'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 19 },
        }}),
        // Slot 'slotAddNewEdge'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QMap<QString,QString> &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 }, { QMetaType::QString, 45 }, { 0x80000000 | 11, 19 },
        }}),
        // Slot 'slotRemoveEdge'
        QtMocHelpers::SlotData<void(const QString &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 47 },
        }}),
        // Slot 'slotRemoveElement'
        QtMocHelpers::SlotData<void(const QString &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 47 },
        }}),
        // Slot 'slotSelectNode'
        QtMocHelpers::SlotData<void(const QString &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotSetHighlighting'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'slotPrepareToSelect'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetCursor'
        QtMocHelpers::SlotData<void(const QCursor &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Slot 'slotUnsetCursor'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeUrl'
        QtMocHelpers::SlotData<bool()>(57, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotLoadLibrary'
        QtMocHelpers::SlotData<bool(graph_t *)>(58, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'slotSetLayoutMethod'
        QtMocHelpers::SlotData<void(LayoutMethod)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 62, 63 },
        }}),
        // Slot 'slotRenameNode'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 65 }, { QMetaType::QString, 66 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGraphViewerPart, qt_meta_tag_ZN12KGraphViewer16KGraphViewerPartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGraphViewer::KGraphViewerPart::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::ReadOnlyPart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer16KGraphViewerPartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer16KGraphViewerPartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KGraphViewer16KGraphViewerPartE_t>.metaTypes,
    nullptr
} };

void KGraphViewer::KGraphViewerPart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGraphViewerPart *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->graphLoaded(); break;
        case 1: _t->newNodeAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->newEdgeAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->removeEdge((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->removeElement((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->selectionIs((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 6: _t->contextMenuEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 7: _t->newEdgeFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[3]))); break;
        case 8: _t->hoverEnter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->hoverLeave((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->slotHide((*reinterpret_cast<std::add_pointer_t<KParts::Part*>>(_a[1]))); break;
        case 11: _t->slotUpdate(); break;
        case 12: _t->prepareAddNewElement((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 13: _t->prepareAddNewEdge((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 14: _t->setReadOnly(); break;
        case 15: _t->setReadWrite(); break;
        case 16: _t->saveTo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->slotRemoveNode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->slotRemoveNodeFromSubgraph((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 19: _t->slotRemoveSubgraph((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->slotAddAttribute((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->slotSetAttribute((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 22: _t->slotRemoveAttribute((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: _t->slotSetGraphAttributes((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 24: _t->slotAddNewNode((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 25: _t->slotAddNewNodeToSubgraph((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 26: _t->slotAddExistingNodeToSubgraph((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 27: _t->slotMoveExistingNodeToMainGraph((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 28: _t->slotAddNewSubgraph((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 29: _t->slotAddNewEdge((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[3]))); break;
        case 30: _t->slotRemoveEdge((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->slotRemoveElement((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->slotSelectNode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: _t->slotSetHighlighting((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->slotPrepareToSelect(); break;
        case 35: _t->slotSetCursor((*reinterpret_cast<std::add_pointer_t<QCursor>>(_a[1]))); break;
        case 36: _t->slotUnsetCursor(); break;
        case 37: { bool _r = _t->closeUrl();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->slotLoadLibrary((*reinterpret_cast<std::add_pointer_t<graph_t*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: _t->slotSetLayoutMethod((*reinterpret_cast<std::add_pointer_t<LayoutMethod>>(_a[1]))); break;
        case 40: _t->slotRenameNode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KParts::Part* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KGraphViewerPart::*)()>(_a, &KGraphViewerPart::graphLoaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGraphViewerPart::*)(const QString & )>(_a, &KGraphViewerPart::newNodeAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGraphViewerPart::*)(const QString & , const QString & )>(_a, &KGraphViewerPart::newEdgeAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGraphViewerPart::*)(const QString & )>(_a, &KGraphViewerPart::removeEdge, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGraphViewerPart::*)(const QString & )>(_a, &KGraphViewerPart::removeElement, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGraphViewerPart::*)(const QList<QString> , const QPoint & )>(_a, &KGraphViewerPart::selectionIs, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGraphViewerPart::*)(const QString & , const QPoint & )>(_a, &KGraphViewerPart::contextMenuEvent, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGraphViewerPart::*)(const QString & , const QString & , const QMap<QString,QString> & )>(_a, &KGraphViewerPart::newEdgeFinished, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGraphViewerPart::*)(const QString & )>(_a, &KGraphViewerPart::hoverEnter, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGraphViewerPart::*)(const QString & )>(_a, &KGraphViewerPart::hoverLeave, 9))
            return;
    }
}

const QMetaObject *KGraphViewer::KGraphViewerPart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGraphViewer::KGraphViewerPart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer16KGraphViewerPartE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KGraphViewerInterface"))
        return static_cast< KGraphViewerInterface*>(this);
    if (!strcmp(_clname, "org.kde.KGraphViewerInterface"))
        return static_cast< KGraphViewer::KGraphViewerInterface*>(this);
    return KParts::ReadOnlyPart::qt_metacast(_clname);
}

int KGraphViewer::KGraphViewerPart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadOnlyPart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    return _id;
}

// SIGNAL 0
void KGraphViewer::KGraphViewerPart::graphLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KGraphViewer::KGraphViewerPart::newNodeAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KGraphViewer::KGraphViewerPart::newEdgeAdded(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KGraphViewer::KGraphViewerPart::removeEdge(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KGraphViewer::KGraphViewerPart::removeElement(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KGraphViewer::KGraphViewerPart::selectionIs(const QList<QString> _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KGraphViewer::KGraphViewerPart::contextMenuEvent(const QString & _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void KGraphViewer::KGraphViewerPart::newEdgeFinished(const QString & _t1, const QString & _t2, const QMap<QString,QString> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void KGraphViewer::KGraphViewerPart::hoverEnter(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KGraphViewer::KGraphViewerPart::hoverLeave(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
