/****************************************************************************
** Meta object code from reading C++ file 'canvasedge.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kgraphviewer-26.04.3/src/part/canvasedge.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'canvasedge.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KGraphViewer10CanvasEdgeE_t {};
} // unnamed namespace

template <> constexpr inline auto KGraphViewer::CanvasEdge::qt_create_metaobjectdata<qt_meta_tag_ZN12KGraphViewer10CanvasEdgeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGraphViewer::CanvasEdge",
        "selected",
        "",
        "CanvasEdge*",
        "Qt::KeyboardModifiers",
        "edgeContextMenuEvent",
        "QPoint",
        "hoverEnter",
        "hoverLeave",
        "modelChanged",
        "slotRemoveEdge"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selected'
        QtMocHelpers::SignalData<void(CanvasEdge *, Qt::KeyboardModifiers)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'edgeContextMenuEvent'
        QtMocHelpers::SignalData<void(const QString &, const QPoint &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 6, 2 },
        }}),
        // Signal 'hoverEnter'
        QtMocHelpers::SignalData<void(CanvasEdge *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'hoverLeave'
        QtMocHelpers::SignalData<void(CanvasEdge *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'modelChanged'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveEdge'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CanvasEdge, qt_meta_tag_ZN12KGraphViewer10CanvasEdgeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGraphViewer::CanvasEdge::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer10CanvasEdgeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer10CanvasEdgeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KGraphViewer10CanvasEdgeE_t>.metaTypes,
    nullptr
} };

void KGraphViewer::CanvasEdge::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CanvasEdge *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selected((*reinterpret_cast<std::add_pointer_t<CanvasEdge*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::KeyboardModifiers>>(_a[2]))); break;
        case 1: _t->edgeContextMenuEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 2: _t->hoverEnter((*reinterpret_cast<std::add_pointer_t<CanvasEdge*>>(_a[1]))); break;
        case 3: _t->hoverLeave((*reinterpret_cast<std::add_pointer_t<CanvasEdge*>>(_a[1]))); break;
        case 4: _t->modelChanged(); break;
        case 5: _t->slotRemoveEdge(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CanvasEdge* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CanvasEdge* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CanvasEdge* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CanvasEdge::*)(CanvasEdge * , Qt::KeyboardModifiers )>(_a, &CanvasEdge::selected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CanvasEdge::*)(const QString & , const QPoint & )>(_a, &CanvasEdge::edgeContextMenuEvent, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CanvasEdge::*)(CanvasEdge * )>(_a, &CanvasEdge::hoverEnter, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CanvasEdge::*)(CanvasEdge * )>(_a, &CanvasEdge::hoverLeave, 3))
            return;
    }
}

const QMetaObject *KGraphViewer::CanvasEdge::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGraphViewer::CanvasEdge::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGraphViewer10CanvasEdgeE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QAbstractGraphicsShapeItem"))
        return static_cast< QAbstractGraphicsShapeItem*>(this);
    return QObject::qt_metacast(_clname);
}

int KGraphViewer::CanvasEdge::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KGraphViewer::CanvasEdge::selected(CanvasEdge * _t1, Qt::KeyboardModifiers _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KGraphViewer::CanvasEdge::edgeContextMenuEvent(const QString & _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KGraphViewer::CanvasEdge::hoverEnter(CanvasEdge * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KGraphViewer::CanvasEdge::hoverLeave(CanvasEdge * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
