/********************************************************************************
** Form generated from reading UI file 'preferencesAppearance.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCESAPPEARANCE_H
#define UI_PREFERENCESAPPEARANCE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_KGraphViewerPreferencesAppearanceWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KColorButton *kcolorbutton;
    QLabel *note;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *KGraphViewerPreferencesAppearanceWidget)
    {
        if (KGraphViewerPreferencesAppearanceWidget->objectName().isEmpty())
            KGraphViewerPreferencesAppearanceWidget->setObjectName("KGraphViewerPreferencesAppearanceWidget");
        KGraphViewerPreferencesAppearanceWidget->resize(455, 109);
        verticalLayout = new QVBoxLayout(KGraphViewerPreferencesAppearanceWidget);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(KGraphViewerPreferencesAppearanceWidget);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        kcolorbutton = new KColorButton(KGraphViewerPreferencesAppearanceWidget);
        kcolorbutton->setObjectName("kcolorbutton");
        kcolorbutton->setColor(QColor(220, 220, 220));
        kcolorbutton->setDefaultColor(QColor(220, 220, 220));

        horizontalLayout->addWidget(kcolorbutton);


        verticalLayout->addLayout(horizontalLayout);

        note = new QLabel(KGraphViewerPreferencesAppearanceWidget);
        note->setObjectName("note");
        QFont font;
        font.setPointSize(16);
        note->setFont(font);
        note->setWordWrap(true);

        verticalLayout->addWidget(note);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(KGraphViewerPreferencesAppearanceWidget);

        QMetaObject::connectSlotsByName(KGraphViewerPreferencesAppearanceWidget);
    } // setupUi

    void retranslateUi(QWidget *KGraphViewerPreferencesAppearanceWidget)
    {
        label->setText(tr2i18n("Default background color:", nullptr));
        note->setText(tr2i18n("Note: this will be overridden if the graph has its own background color", nullptr));
        (void)KGraphViewerPreferencesAppearanceWidget;
    } // retranslateUi

};

namespace Ui {
    class KGraphViewerPreferencesAppearanceWidget: public Ui_KGraphViewerPreferencesAppearanceWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFERENCESAPPEARANCE_H

